Tools for the identification of unique multilocus genotypes when both genotyping error and missing data may be present; targeted for use with large datasets and databases containing multiple samples of each individual (a common situation in conservation genetics, particularly in non-invasive wildlife sampling applications). Functions explicitly incorporate missing data and can tolerate allele mismatches created by genotyping error.
Paul Galpern (pgalpern@gmail.com), Todd Cross (todd.cross@gmail.com)
| Package: | allelematch |
| Type: | Package |
| Version: | 3.0.0 |
| Date: | 2026-07-23 |
| License: | GPL (>= 2) |
| Requires: | dynamicTreeCut |
| LazyLoad: | yes |
amDataset: Produces an input dataset object for allelematch routines.
amPreCheck: Pre-screens an amDataset object for severe missing data loads to prevent runtime sorting failures.
amMatrix: Produces a dissimilarity matrix.
amPairwise: Performs pairwise matching of genotypes.
amCluster: Clusters genotypes using dynamic tree cutting.
amAlleleFreq: Produces allele frequencies from an amDataset object.
amUnique: Identifies unique genotypes.
amUniqueProfile: Finds optimal parameters for amUnique.
The complete user manual and analytical tutorials describing the operation of the software
in detail are included locally as a package vignette. It is installed automatically with
the package and can be accessed within an active R session using vignette("allelematch").
Simulations examining the performance of these tools have also been performed, and results are
available in the publication associated with this package. Please refer to the publication:
Galpern P, Manseau, M, Hettinga P, Smith K, and Wilson P. (2012) allelematch: an R package for
identifying unique multilocus genotypes where genotype error and missing data may be present.
Molecular Ecology Resources 12:771-778.
Use citation("allelematch") for the full citation. Please also use this publication when
citing the package.
An important core element of the package is dynamic tree cutting, and this is made possible via the cutreeHybrid function within the dynamicTreeCut package for R (Langfelder et al., 2008).